# SKITSO

    greek for drafting


# What is it?

skitso it's a lightweight scenes generator. It may be think as newborn nefew of [manim](https://docs.manim.community/en/stable/index.html).

        It's way smaller, and it's somehow related.

With very simple shape primitives you can define your scene, and you have to explicitely take snapshots you want to persist. That's it'

